package com.gic.haoban.manage.service.service.licence.impl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.gic.commons.util.DateUtil;
import com.gic.commons.util.UniqueIdUtils;
import com.gic.haoban.manage.api.dto.qdto.licence.LicenceOrderQDTO;
import com.gic.haoban.manage.service.dao.mapper.licence.TabHaobanLicenceOrderMapper;
import com.gic.haoban.manage.service.dao.mapper.licence.TabHaobanLicenceOrderProgressMapper;
import com.gic.haoban.manage.service.entity.licence.TabHaobanLicenceOrder;
import com.gic.haoban.manage.service.entity.licence.TabHaobanLicenceOrderProgress;
import com.gic.haoban.manage.service.service.licence.LicenceOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * @description:
 * @Author: wenhua
 * @Date: 2023/3/9 17:01
 */
public class LicenceOrderServiceImpl implements LicenceOrderService {

    @Autowired
    private TabHaobanLicenceOrderMapper tabHaobanLicenceOrderMapper;
    @Autowired
    private TabHaobanLicenceOrderProgressMapper tabHaobanLicenceOrderProgressMapper;

    @Override
    public TabHaobanLicenceOrder getLicenceOrderDetail(Long orderId) {
        TabHaobanLicenceOrder tabHaobanLicenceOrder = tabHaobanLicenceOrderMapper.selectById(orderId);
        return tabHaobanLicenceOrder;
    }

    @Override
    public Integer deleteLicenceOrder(Long orderId) {
        return tabHaobanLicenceOrderMapper.deleteById(orderId);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveOrUpdateLicenceOrder(LicenceOrderQDTO licenceOrderQDTO) {
        if(ObjectUtil.isNull(licenceOrderQDTO.getOrderId())){
            //订单不支持修改，只能新增
            TabHaobanLicenceOrder order = JSONObject.parseObject(JSONObject.toJSONString(licenceOrderQDTO), TabHaobanLicenceOrder.class);
            Date now = new Date();
            long orderId = UniqueIdUtils.uniqueLong();
            order.setOrderId(orderId);
            order.setCreateTime(now);
            order.setUpdateTime(now);
            Date expireTime;
            if(order.getPayType()==1){
                expireTime = DateUtil.addNumForMinute(now, 30);
            }else {
                //生成订单编号
                String num = "ZH"+UniqueIdUtils.uniqueLong();
                order.setTransactionId(num);
                expireTime = DateUtil.addDay(now, 3);
            }
            order.setExpireTime(expireTime);
            tabHaobanLicenceOrderMapper.insert(order);
            //记录订单进度
            saveOrderProgress(orderId,"创建订单",licenceOrderQDTO.getEnterpriseId(),licenceOrderQDTO.getWxEnterpriseId(),licenceOrderQDTO.getCreatorName());
        }
    }

    private void saveOrderProgress(Long orderId,String orderStatus,String enterpriseId,String wxEnterpriseId,String creatorName){
        TabHaobanLicenceOrderProgress orderProgress = new TabHaobanLicenceOrderProgress();
        orderProgress.setId(UniqueIdUtils.uniqueLong());
        orderProgress.setEnterpriseId(enterpriseId);
        orderProgress.setWxEnterpriseId(wxEnterpriseId);
        orderProgress.setOrderId(orderId);
        orderProgress.setOrderStatus(orderStatus);
        orderProgress.setType(1);
        orderProgress.setCreatorName(creatorName);
        tabHaobanLicenceOrderProgressMapper.insert(orderProgress);
    }
    @Override
    public Boolean updateLicenceOrderType(Long orderId, Integer type) {

        return null;
    }

    @Override
    public Boolean uploadLicenceOrderVoucher(Long orderId, String voucher) {
        return null;
    }

    @Override
    public String isPayLicenceOrder(String wxEnterpriseId) {
        String orderId = tabHaobanLicenceOrderMapper.selectByWxEnterpriseId(wxEnterpriseId);
        if (StrUtil.isNotBlank(orderId)){
            return orderId;
        }
        return null;
    }
}
